@@ -28,7 +28,7 @@ impl Asn1ResolvedCharacterString {
         let struct_tokens = quote! {
             #[derive(Debug, AperCodec)]
             #[asn(#ty_attributes)]
-            pub struct #struct_name(String);
+            pub struct #struct_name(pub String);
         };
 
         Ok(struct_tokens)
@@ -38,7 +38,7 @@ impl Asn1ResolvedCharacterString {
         &self,
         generator: &mut Generator,
     ) -> Result<Ident, Error> {
-        let unique_name = generator.to_unique_name("CharacterString");
+        let unique_name = generator.get_unique_name("CharacterString");
 
         let item = self.generate(&unique_name, generator)?;
         generator.aux_items.push(item);
