@@ -26,7 +26,7 @@ impl Asn1ResolvedOctetString {
         let struct_tokens = quote! {
             #[derive(Debug, AperCodec)]
             #[asn(#ty_attributes)]
-            pub struct #struct_name(Vec<u8>);
+            pub struct #struct_name(pub Vec<u8>);
         };
 
         Ok(struct_tokens)
@@ -36,7 +36,7 @@ impl Asn1ResolvedOctetString {
         &self,
         generator: &mut Generator,
     ) -> Result<Ident, Error> {
-        let unique_name = generator.to_unique_name("OCTET STRING");
+        let unique_name = generator.get_unique_name("OCTET STRING");
 
         let item = self.generate(&unique_name, generator)?;
         generator.aux_items.push(item);
