@@ -22,7 +22,7 @@ impl ResolvedConstructedType {
         } = self
         {
             let seq_of_type_ident = generator.to_type_ident(name);
-            let input_type_name = format!("{}_Item", name);
+            let input_type_name = format!("{}_Entry", name);
 
             let mut ty_attrs = quote! { type = "SEQUENCE-OF" };
             if size_values.is_some() {
@@ -43,7 +43,7 @@ impl ResolvedConstructedType {
             Ok(quote! {
                 #[derive(Debug, AperCodec)]
                 #[asn(#ty_attrs)]
-                pub struct #seq_of_type_ident(Vec<#seq_of_type>);
+                pub struct #seq_of_type_ident(pub Vec<#seq_of_type>);
             })
         } else {
             Ok(TokenStream::new())
