@@ -1,6 +1,6 @@
 //! Code Generation module
 
-use heck::{ShoutySnakeCase, SnakeCase};
+use heck::{ToShoutySnakeCase, ToSnakeCase};
 use proc_macro2::{Ident, Literal, Span, TokenStream};
 
 use quote::quote;
@@ -46,8 +46,8 @@ impl Generator {
         let mut items = vec![];
         for (k, t) in resolver.get_resolved_types() {
             let item = Asn1ResolvedType::generate_for_type(k, t, self)?;
-            if item.is_some() {
-                items.push(item.unwrap())
+            if let Some(it) = item {
+                items.push(it)
             }
         }
 
@@ -57,18 +57,19 @@ impl Generator {
 
         self.items.extend(items);
 
-        Ok(format!(
-            "{}",
-            self.items
-                .iter()
-                .map(|t| t.to_string())
-                .collect::<Vec<String>>()
-                .join("\n\n")
-        ))
+        Ok(self
+            .items
+            .iter()
+            .map(|t| t.to_string())
+            .collect::<Vec<String>>()
+            .join("\n\n"))
     }
 
     pub(crate) fn to_type_ident(&self, name: &str) -> Ident {
-        Ident::new(&name.replace("-", "_").replace(" ", "_"), Span::call_site())
+        Ident::new(
+            &capitalize_first(name).replace("-", "_").replace(" ", "_"),
+            Span::call_site(),
+        )
     }
 
     pub(crate) fn to_const_ident(&self, name: &str) -> Ident {
@@ -76,8 +77,8 @@ impl Generator {
     }
 
     pub(crate) fn to_value_ident(&self, name: &str) -> Ident {
-        let mut val = name.to_snake_case();
-        if val == "type".to_string() {
+        let mut val = capitalize_first(name).to_snake_case();
+        if val == *"type" {
             val = "typ".to_string()
         }
         Ident::new(&val, Span::call_site())
@@ -123,7 +124,7 @@ impl Generator {
         }
     }
 
-    pub(crate) fn to_unique_name(&mut self, name: &str) -> String {
+    pub(crate) fn get_unique_name(&mut self, name: &str) -> String {
         self.counter += 1;
 
         format!("{} {}", name, self.counter)
@@ -142,3 +143,42 @@ impl Generator {
         }
     }
 }
+
+fn capitalize_first(input: &str) -> String {
+    if !input.is_empty() {
+        let mut input = input.to_string();
+        let (first, _) = input.split_at_mut(1);
+        first.make_ascii_uppercase();
+
+        input
+    } else {
+        input.to_string()
+    }
+}
+
+#[cfg(test)]
+mod tests {
+
+    use super::*;
+
+    #[test]
+    fn test_capitalize_first_empty() {
+        let empty = "".to_string();
+        let capitalized = capitalize_first(&empty);
+        assert_eq!(capitalized, empty);
+    }
+
+    #[test]
+    fn test_capitalize_first_single_letter() {
+        let empty = "a".to_string();
+        let capitalized = capitalize_first(&empty);
+        assert_eq!(capitalized, "A");
+    }
+
+    #[test]
+    fn test_capitalize_first_word() {
+        let empty = "amfTnlAssociationToAddItem".to_string();
+        let capitalized = capitalize_first(&empty);
+        assert_eq!(capitalized, "AmfTnlAssociationToAddItem");
+    }
+}
